/**************************************************************************** 
*  Copyright 2007 C&H Technologies, Inc.  All Rights Reserved.					    * 
*****************************************************************************/
/****************************************************************************
*
*	ma200_ansi.h
*
*	Header file for the ma200 ANSI-C driver. 
*
*	C&H Part Number: 11027869 
*
*****************************************************************************/
#ifndef	MA200_HEADER
#define	MA200_HEADER	


#ifndef	PLATFORM
#define PLATFORM chwin
#endif

#include	"apis.h"

/**************************************************************************** 
*  TypeDef's
*****************************************************************************/
typedef char Int8;
typedef unsigned char UInt8;
typedef unsigned short UInt16;
typedef int Int32;
typedef unsigned int UInt32;
typedef unsigned short Bool;
typedef double Real64;

typedef struct
{	APIS_HANDLE apis_handle;
	UInt32			apis_error;
	Int32	input;
}MA200_INSTR, *MA200_HANDLE;


/**************************************************************************** 
*  Error Codes
*****************************************************************************/
#define		MA200_SUCCESS															0

#define		MA200_SPECIFIC_ERROR_BASE									0xBFFC0900
#define		MA200_ERROR_RESERVED_VALUE								(MA200_SPECIFIC_ERROR_BASE + 0)
#define		MA200_ERROR_RUNNING												(MA200_SPECIFIC_ERROR_BASE + 1)
#define		MA200_ERROR_FIFO_EMPTY										(MA200_SPECIFIC_ERROR_BASE + 2)
#define		MA200_ERROR_UNINITIALIZED_INPUT_MODE			(MA200_SPECIFIC_ERROR_BASE + 3)
#define		MA200_ERROR_PARAMETER1										(MA200_SPECIFIC_ERROR_BASE + 4)
#define		MA200_ERROR_PARAMETER2										(MA200_SPECIFIC_ERROR_BASE + 5)
#define		MA200_ERROR_PARAMETER3										(MA200_SPECIFIC_ERROR_BASE + 6)
#define		MA200_ERROR_PARAMETER4										(MA200_SPECIFIC_ERROR_BASE + 7)
#define		MA200_ERROR_FAIL_ID_QUERY									(MA200_SPECIFIC_ERROR_BASE + 8)
#define		MA200_ERROR_APIS													(MA200_SPECIFIC_ERROR_BASE + 9)
#define		MA200_ERROR_OUT_OF_MEMORY									(MA200_SPECIFIC_ERROR_BASE + 10)	
#define		MA200_SPECIFIC_ERROR_END									(MA200_SPECIFIC_ERROR_BASE + 11)
#define		MA200_SPECIFIC_ERROR_ABSOLUTE_MAX					(MA200_SPECIFIC_ERROR_BASE + 0x1FFF)


/**************************************************************************** 
*  Warning Codes
*****************************************************************************/
#define		MA200_SPECIFIC_WARNING_BASE														0x3FFC0900
#define		MA200_SPECIFIC_WARNING_NUM_SAMPLES_NOT_AVAILABLE			(MA200_SPECIFIC_WARNING_BASE + 0)
#define		MA200_SPECIFIC_WARNING_END														(MA200_SPECIFIC_WARNING_BASE + 1)
#define		MA200_SPECIFIC_WARNING_ABSOLUTE_MAX										(MA200_SPECIFIC_WARNING_BASE + 0x6FF)


/**************************************************************************** 
*  M-Module ID Words
*****************************************************************************/
#define		MA200_IDENT_WORD_SYNC_CODE				0
#define		MA200_IDENT_WORD_MODULE_NUM				1
#define		MA200_IDENT_WORD_REVISION_NUM 		2
#define		MA200_IDENT_WORD_MODULE_CHAR 			3
#define		MA200_IDENT_WORD_VXI_SYNC_CODE 		16
#define		MA200_IDENT_WORD_VXI_ID 					17
#define		MA200_IDENT_WORD_VXI_DEVICE_TYPE  18

#define		MA200_VXI_MANF_ID				0xFC1
#define		MA200_VXI_MODEL_CODE		0xFEC


/**************************************************************************** 
*	MA200 Register offsets
*****************************************************************************/
#define		MA200_CONTROL_STATUS_REGISTER						0x00
#define		MA200_INTERRUPT_CONTROL_REGISTER				0x02
#define		MA200_APERTURE_HIGH_REGISTER						0x04
#define		MA200_APERTURE_LOW_REGISTER							0x06
#define		MA200_FIFO_DATA_REGISTER								0x08
#define		MA200_CALIBRATION_REGISTER							0x0A
#define		MA200_ACCESSORY_MODULE_REGISTER					0x0C
#define		MA200_LAST_VALUE_STORED_REGISTER				0x0E
#define		MA200_FIFO_UNREAD_COUNT_REGISTER				0x10
#define		MA200_ID_ACCESS_REGISTER								0xFE


/**************************************************************************** 
*	Bit Definitions
*****************************************************************************/
/*  Status/Control Register  */
#define		MA200_RUN_BIT									0x0001
#define		MA200_RESET_TIME_STAMP_BIT		0x0002
#define		MA200_CLOCK_SPEED_ERROR_BIT		0x0002
#define		MA200_RESET_FIFO_BIT					0x0004
#define		MA200_CNV_BIT									0x0008
#define		MA200_RUN_SEL_BITS						0x0070
#define		MA200_STORE_ALL_BIT						0x0080
#define		MA200_CLKSEL_BITS							0x0700
#define		MA200_PSC_BITS								0x1800
#define		MA200_FIFO_HALF_FULL_BIT			0x2000
#define		MA200_FIFO_FULL_BIT						0x4000
#define		MA200_DATA_STORED_BIT					0x8000
#define		MA200_STATUS_BITS							0xE000

/*  Interrupt Control Register  */
#define		MA200_INTERRUPT_VECTOR_BITS		0x00FF
#define		MA200_INTERRUPT_ENABLE_BITS		0xE000

/*  Fifo Data Port Register  */
#define		MA200_DATA_VALID_BIT					0x8000

/*  Accessory Module Register  */
#define		MA200_ACCESSORY_ENABLE_BIT		0x8000
#define		MA200_ACCESSORY_CONTROL_BITS	0x000F

/*  Calibration Register  */
#define		MA200_CALIBRATION_CLOCK_BIT		0x0001
#define		MA200_CALIBRATE_UP_DOWN_BIT		0x0002			

#define		MA200_CALIBRATE_FULL_SCALE		0x0010
#define		MA200_CALIBRATE_OFFSET				0x0030


/**************************************************************************** 
*	Input Modes and Ranges
*****************************************************************************/
#define		MA200_INPUT_MODE_BIPOLAR	0
#define		MA200_INPUT_MODE_UNIPOLAR	1
#define		MA200_INPUT_RANGE_20VPP		0
#define		MA200_INPUT_RANGE_10VPP		1


#define		MA200_CAL_FS_UP					0
#define		MA200_CAL_FS_DOWN				1
#define		MA200_CAL_OFFSET_UP			2
#define		MA200_CAL_OFFSET_DOWN		3


/**************************************************************************** 
*	Misc.
*****************************************************************************/
#define		MA200_TRUE					1
#define		MA200_FALSE					0


/**************************************************************************** 
*	Exported Function Prototypes
*****************************************************************************/
Int32 ma200_Init (Int32 instr, Bool IDQuery,
                                Bool reset, MA200_HANDLE *handle);
Int32 ma200_SetInputModeAndRange (MA200_HANDLE handle,
                                                Bool inputMode,
                                                Bool inputRange);
Int32 ma200_ConfigureSampleClock (MA200_HANDLE handle,
                                                Int32 clockSource,
                                                Int32 clockPrescaler);
Int32 ma200_ConfigureRunSource (MA200_HANDLE handle, Int32 runSource);
Int32 ma200_StoreAll (MA200_HANDLE handle, Bool storeAll);
Int32 ma200_SetAperture (MA200_HANDLE handle, Real64 apertureHigh, Real64 apertureLow);
Int32 ma200_SetRawAperture (MA200_HANDLE handle, UInt16 apertureHigh, UInt16 apertureLow);
Int32 ma200_EnableInterrupts (MA200_HANDLE handle,  Bool dataStored, Bool fifoFull, Bool fifoHalfFull);
Int32 ma200_UninstallIrq (MA200_HANDLE handle);
Int32 ma200_InstallIrq (MA200_HANDLE handle, void *interruptHandler, Int32 vector, Int32 level, Int32 mode, void *var_ptr);

Int32 ma200_AccessoryModuleEnable (MA200_HANDLE handle, Bool enable);

Int32 ma200_SetCutOffFrequency (MA200_HANDLE handle, Int32 cutoffFrequency);

Int32 ma200_Run (MA200_HANDLE handle);
Int32 ma200_Stop (MA200_HANDLE handle);
Int32 ma200_SingleSample (MA200_HANDLE handle);
Int32 ma200_LastStoredValue (MA200_HANDLE handle,
                                           UInt16 *lastStoredValue);
Int32 ma200_CalibrationControl (MA200_HANDLE handle, Int32 controlFunction);
Int32 ma200_ClockSpeedError (MA200_HANDLE handle,
                                           Bool *clockSpeedError);
Int32 ma200_ReadFifo (MA200_HANDLE handle, UInt32 *timeStamp,
                                    Real64 *value, UInt16 *rawData);
Int32 ma200_ReadRawFifo (MA200_HANDLE handle, UInt32 *timeStamp, UInt16 *value);
Int32 ma200_ReadFifoBuffer (MA200_HANDLE handle, Int32 count, UInt32 *timeStamp, Real64 *value, UInt16 *rawData, UInt32 *num_read);
Int32 ma200_ReadRawFifoBuffer (MA200_HANDLE handle, Int32 count, UInt32 *timeStamp, UInt16 *rawData, UInt32 *num_read);


Int32 ma200_ResetFifo (MA200_HANDLE handle);
Int32 ma200_FifoUnreadCount (MA200_HANDLE handle, UInt16 *unreadCount);
Int32 ma200_GetFifoStatus (MA200_HANDLE handle, Bool *fifoFull,
                                         Bool *fifoHalfFull,
                                         Bool *dataStored);
Int32 ma200_ResetTimeStamp (MA200_HANDLE handle);
Int32 ma200_ClearInterrupts (MA200_HANDLE handle, Bool dataStored,
                                           Bool fifoFull,
                                           Bool fifoHalfFull);
Int32 ma200_GetInterruptPending (MA200_HANDLE handle,
                                               Bool *fifoFull,
                                               Bool *fifoHalfFull,
                                               Bool *dataStored);
Int32 ma200_Reset (MA200_HANDLE handle);
Int32 ma200_RevisionQuery (Int8 driverRev[]);
Int32 ma200_ErrorMessage (Int32 statusCode, Int8 errorMessage[]);
Int32 ma200_ReadRegister (MA200_HANDLE handle, UInt16 offset,
                                        UInt16 *value);
Int32 ma200_WriteRegister (MA200_HANDLE handle, UInt16 offset,
                                         UInt16 value);
Int32 ma200_GetIdentWord (MA200_HANDLE handle, UInt16 offset,
                                        UInt16 *value);
Int32 ma200_Close (MA200_HANDLE handle);

Int32 ma200_GetApisError (MA200_HANDLE handle, UInt32 *apis_error);



#endif






